@@ -27,7 +27,10 @@ def __clean():
     """
     程序退出清理操作。
     """
-    loop = asyncio.get_event_loop()
+    try:
+        loop = asyncio.get_event_loop()
+    except RuntimeError:
+        return
 
     async def __clean_task():
         await __session_pool[loop].close()
@@ -58,7 +61,7 @@ async def request(
         data       (Any, optional)       : 请求载荷。
         credential (Credential, optional): Credential 类。
         no_csrf    (bool, optional)      : 不要自动添加 CSRF。
-        json_body (bool, optional) 载荷是否为 JSON
+        json_body  (bool, optional)      : 载荷是否为 JSON
 
     Returns:
         接口未返回数据时，返回 None，否则返回该接口提供的 data 或 result 字段的数据。
@@ -178,7 +181,7 @@ def get_session():
     if session is None or last_proxy != settings.proxy:
         if settings.proxy != "":
             last_proxy = settings.proxy
-            proxies = {settings.proxy_use: settings.proxy}
+            proxies = {"all://": settings.proxy}
             session = httpx.AsyncClient(proxies=proxies)
         else:
             last_proxy = ""
